body {
    background: #fff;
}

div.center-container {
    width: 779px;
    height: 615px;
}

.ts-arrow {
    color: #eee;
}

.ts-button {
    color: #fff;
    border-radius: 5px;
    text-shadow: 1px 1px 2px #444;
    background: #1F3451;
    border-color: #1f2836;
    background: linear-gradient(45deg, #1F3451 0%, #2B3D6B 100%);
    box-shadow: 0 0 2px #333;
}

.ts-button:focus,
.ts-button:hover {
    color: #fff;
    text-shadow: 1px 1px 2px #444;
    background: #1F3451;
    border-color: #1f2836;
    background: linear-gradient(45deg, #2B3D6B 0%, #1F3451 100%);
}

#ts-continue-button {
    position: relative;
    bottom: 65px;
}
